@@ -51,11 +51,12 @@
 //! [struct docs]: struct.Bytes.html
 
 #![deny(
-    warnings,
+//    warnings,
 //    missing_docs,
 //    missing_debug_implementations,
     rust_2018_idioms
 )]
+#![allow(clippy::return_self_not_must_use)]
 #![doc(html_root_url = "https://docs.rs/ntex-bytes/")]
 
 pub mod buf;
