@@ -26,9 +26,7 @@ fn test_size() {
     assert_eq!(32, std::mem::size_of::<Option<Bytes>>());
 
     let mut t = BytesMut::new();
-    t.extend_from_slice(
-        &b"\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"[..],
-    );
+    t.extend_from_slice(&b"\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"[..]);
 
     let val = t.freeze();
     assert!(val.is_inline());
